package com.ruoyi.model.mapper;

import java.util.List;
import com.ruoyi.model.domain.PetType;

/**
 * 宠物类型Mapper接口
 * 
 * @author ruoyi
 * @date 2025-03-05
 */
public interface PetTypeMapper 
{
    /**
     * 查询宠物类型
     * 
     * @param petTypeId 宠物类型主键
     * @return 宠物类型
     */
    public PetType selectPetTypeByPetTypeId(Long petTypeId);

    /**
     * 查询宠物类型列表
     * 
     * @param petType 宠物类型
     * @return 宠物类型集合
     */
    public List<PetType> selectPetTypeList(PetType petType);

    /**
     * 新增宠物类型
     * 
     * @param petType 宠物类型
     * @return 结果
     */
    public int insertPetType(PetType petType);

    /**
     * 修改宠物类型
     * 
     * @param petType 宠物类型
     * @return 结果
     */
    public int updatePetType(PetType petType);

    /**
     * 删除宠物类型
     * 
     * @param petTypeId 宠物类型主键
     * @return 结果
     */
    public int deletePetTypeByPetTypeId(Long petTypeId);

    /**
     * 批量删除宠物类型
     * 
     * @param petTypeIds 需要删除的数据主键集合
     * @return 结果
     */
    public int deletePetTypeByPetTypeIds(Long[] petTypeIds);

    /**
     * 查询宠物类型列表
     *
     * @return 宠物类型集合
     */
    List<PetType> getPetTypeList();
}
